local Shot = require 'shot'

local screenWidth = love.graphics.getWidth()
local screenHeight = love.graphics.getHeight()
local ENEMY_SHOT_INACCURACY = 35
local ENEMY_RELOAD_TIME_MIN = 1
local ENEMY_RELOAD_TIME_MAX = 5

Enemy = {}
Enemy.__index = Enemy

function Enemy:new()
  local self = setmetatable({}, Enemy)
  self.image = love.graphics.newImage("assets/enemyShip.png")
  self.shots = {}
	self.x = love.math.random(0, screenWidth)
	self.y = love.math.random(0, screenHeight/2)
	self.futureX = love.math.random(0, screenWidth)
	self.futureY = love.math.random(0, screenHeight)
	self.speed = 100
  self.reloadTime =  love.math.random(ENEMY_RELOAD_TIME_MIN, ENEMY_RELOAD_TIME_MAX)
  self.removeMe = false
  return self
end

function Enemy:newReloadTime()
  self.reloadTime = love.math.random(ENEMY_RELOAD_TIME_MIN, ENEMY_RELOAD_TIME_MAX)
end

function Enemy:readyToFire()
  return self.reloadTime < 0
end

function Enemy:reset()
  self.x = screenWidth/4
  self.y = screenHeight/4
  self.futureX = love.math.random(0, screenWidth)
  self.futureY = love.math.random(0, screenHeight)
  self.shots = {}
end

function Enemy:update(dt)  
	if self.x > self.futureX + self.speed then
		self.x = self.x - self.speed * dt
	elseif self.x < self.futureX - self.speed then
		self.x = self.x + self.speed * dt
	else
		self.futureX = love.math.random(0, screenWidth)
	end 

	if self.y > self.futureY + self.speed then
		self.y = self.y - self.speed * dt
	elseif self.y < self.futureY - self.speed then
		self.y = self.y + self.speed * dt
	else
		self.futureY = love.math.random(0, screenHeight)
	end
  
  self.reloadTime = self.reloadTime - dt

	if self:readyToFire() then
    self:newReloadTime()
		local angleToPlayer = math.atan2(player.y - self.y, player.x - self.x)
    local inaccuracy = love.math.random(-ENEMY_SHOT_INACCURACY, ENEMY_SHOT_INACCURACY) / 100
    table.insert(self.shots, Shot:new(self.x, self.y, 0, 0, angleToPlayer + inaccuracy, true))    
	end
  
  for i,v in ipairs(self.shots) do
    self.shots[i]:update(dt)
  end
end

function Enemy:draw()
  love.graphics.draw(self.image, self.x, self.y, 0, 0.5, 0.5, 98/2, 50/2)
  for i,v in ipairs(self.shots) do
    self.shots[i]:draw()
  end
end

return Enemy