local Shot = require 'shot'

local screenWidth = love.graphics.getWidth()
local screenHeight = love.graphics.getHeight()
local MAX_SHOTS = 6
local SHOT_DELAY = 0.2

player = {
  image = love.graphics.newImage("assets/playerShip.png"),
  shots = {},
  shotTimer = 0,
	x = screenWidth/2,
	y = screenHeight - screenHeight/4,
	rotation = -math.pi/2,
	rotationSpeed = 4,
	velocityX = 0,
	velocityY = 0,
	thrustPower = 10,
	thrustDecay = 0.99
}

function player:reset()
  self.x = screenWidth / 2
  self.y = screenHeight - screenHeight / 4
  self.rotation = -math.pi/2
  self.velocityX = 0
  self.velocityY = 0
  self.shots = {}
end  

function player.getInput(dt)  -- Player controls
  if love.keyboard.isDown('right') then
		player.rotation = player.rotation + player.rotationSpeed * dt
	elseif love.keyboard.isDown('left') then
		player.rotation = player.rotation - player.rotationSpeed * dt
	end

	if love.keyboard.isDown('up') then
		player.velocityX = player.velocityX + math.cos(player.rotation) * player.thrustPower
		player.velocityY = player.velocityY + math.sin(player.rotation) * player.thrustPower
	end
  
  if love.keyboard.isDown(' ') then
    player:shoot()
  end
end

function player:update(dt)
	player.getInput(dt)
  
  -- Update player position
	self.x = self.x + self.velocityX * dt
	self.y = self.y + self.velocityY * dt
	self.velocityX = self.velocityX * self.thrustDecay
	self.velocityY = self.velocityY * self.thrustDecay
  
  -- wrap around edges of screen
	if self.x > screenWidth then
		self.x = self.x - screenWidth
	end
	if self.x < 0 then
		self.x = self.x + screenWidth
	end
	if self.y < 0 then
		self.y = self.y + screenHeight
	end
	if self.y > screenHeight then
		self.y = self.y - screenHeight
	end
  
  for i=#self.shots,1,-1 do
    if self.shots[i].removeMe == true then
      table.remove(self.shots, i)
    else
      self.shots[i]:update(dt)
    end
  end
  
  if self.shotTimer > 0 then
    self.shotTimer = self.shotTimer - dt
  end
end

function player:draw()
	love.graphics.draw(self.image, self.x, self.y, self.rotation + math.pi/2, 0.5, 0.5, 99/2, 75/2)
  for i,v in ipairs(self.shots) do
    v:draw()
  end
end

function player:shoot()
  if #self.shots < MAX_SHOTS and self.shotTimer <= 0 then
    table.insert(self.shots, Shot:new(self.x, self.y, self.velocityX, self.velocityY, self.rotation, false))
    self.shotTimer = self.shotTimer + SHOT_DELAY
  end
end

return player