local screenWidth = love.graphics.getWidth()
local screenHeight = love.graphics.getHeight()
local SHOT_LIFE = 70
local SHOT_SPEED = 500

local Shot = {}
Shot.__index = Shot

local function getDist(x1, y1, x2, y2)
	return math.sqrt((x1 - x2)^2 + (y1 - y2)^2)
end

function Shot:new(x, y, vX, vY, angle, fromEnemy)
  local self = setmetatable({}, Shot)
  self.x = x
  self.y = y
  self.vX = vX + math.cos(angle) * SHOT_SPEED
  self.vY = vY + math.sin(angle) * SHOT_SPEED
  self.fromEnemy = fromEnemy or false
  self.lifeCycles = SHOT_LIFE
  self.removeMe = false
  return self
end

function Shot:reset()
  self.lifeCycles = 0
end

function Shot:isActive()
  return self.lifeCycles > 0
end

function Shot:update(dt)
  if self.lifeCycles > 0 then
		self.x = self.x + self.vX * dt
		self.y = self.y + self.vY * dt

		if self.x > screenWidth then
			self.x = self.x - screenWidth
		end
		if self.x < 0 then
			self.x = self.x + screenWidth
		end
		if self.y < 0 then
			self.y = self.y + screenHeight
		end
		if self.y > screenHeight then
			self.y = self.y - screenHeight
		end

		self.lifeCycles = self.lifeCycles - 1
  
    -- Collision rules (should probably be moved to game.lua?)
    if self.fromEnemy then
      if getDist(player.x, player.y, self.x, self.y) < 30 then
        player:reset()
        self:reset()
      end
    else
      for i=#enemies,1,-1 do
        if getDist(enemies[i].x, enemies[i].y, self.x, self.y) < 30 then
          enemies[i].removeMe = true
          self:reset()
        end
      end
    end
  else
    self.removeMe = true
  end
end

function Shot:draw()
	if self.lifeCycles > 0 then
		love.graphics.setColor(255, 255, 255)
		love.graphics.circle('fill', self.x, self.y, 3)
	end
end

return Shot